@@ -44,7 +44,7 @@ for sourceview in "gtksourceview sourceview".split():
     except ImportError:
         pass
 
-version = "1.1.4"
+version = "1.1.5"
 
 # magic developer switch, changes some behaviour
 developer = 0
@@ -89,6 +89,8 @@ class NewDocDialog(gnomeglade.Component):
             paths = [ e.get_full_path(0) or "" for e in self.entrylists[page] ]
             if page < 2 and not self.three_way_compare[page].get_active():
                 paths.pop(0)
+            for path in paths:
+                self.entrylists[page][0].gnome_entry().append_history(True, path)
             methods = (self.parentapp.append_filediff,
                        self.parentapp.append_dirdiff,
                        self.parentapp.append_vcview )
@@ -290,11 +292,11 @@ class PreferencesDialog(gnomeglade.Component):
     def on_checkbutton_show_line_numbers_toggled(self, check):
         self.prefs.show_line_numbers = check.get_active()
         if check.get_active() and not sourceview_available:
-            misc.run_dialog(_("Line numbers are only available if you have pysourceview installed.") )
+            misc.run_dialog(_("Line numbers are only available if you have gnome-python-desktop installed.") )
     def on_checkbutton_use_syntax_highlighting_toggled(self, check):
         self.prefs.use_syntax_highlighting = check.get_active()
         if check.get_active() and not sourceview_available:
-            misc.run_dialog(_("Syntax highlighting is only available if you have pysourceview installed.") )
+            misc.run_dialog(_("Syntax highlighting is only available if you have gnome-python-desktop installed.") )
     def on_editor_command_toggled(self, radio):
         if radio.get_active():
             idx = self.editor_command.index(radio)
@@ -380,13 +382,14 @@ class NotebookLabel(gtk.HBox):
         gtk.HBox.__init__(self)
         self.label = gtk.Label(text)
         self.button = gtk.Button()
+        self.button.set_relief(gtk.RELIEF_NONE)
+        image = gtk.Image()
+        image.set_from_stock( gtk.STOCK_CLOSE, gtk.ICON_SIZE_MENU)
+        image.set_size_request( 10,10 ) #TODO font height
+        self.button.add( image )
         icon = gtk.Image()
         icon.set_from_file( paths.share_dir("glade2/pixmaps/%s" % iconname) )
-        icon.set_from_pixbuf( icon.get_pixbuf().scale_simple(15, 15, 2) ) #TODO font height
-        image = gtk.Image()
-        image.set_from_file( paths.share_dir("glade2/pixmaps/button_delete.xpm") )
-        image.set_from_pixbuf( image.get_pixbuf().scale_simple(9, 9, 2) ) #TODO font height
-        self.button.add( image )
+        icon.set_from_pixbuf( icon.get_pixbuf().scale_simple(15, 15, 2) ) #TODO stock image
         self.pack_start( icon )
         self.pack_start( self.label )
         self.pack_start( self.button, expand=0 )
@@ -439,11 +442,7 @@ class MeldPreferences(prefs.Preferences):
             #TRANSLATORS: translate this string ONLY to the first "\t", leave it and the following parts intact
             _("Backups\t1\t#*# .#* ~* *~ *.{orig,bak,swp}\n") + \
             #TRANSLATORS: translate this string ONLY to the first "\t", leave it and the following parts intact
-            _("CVS\t1\tCVS\n") + \
-            #TRANSLATORS: translate this string ONLY to the first "\t", leave it and the following parts intact
-            _("SVN\t1\t.svn\n") + \
-            #TRANSLATORS: translate this string ONLY to the first "\t", leave it and the following parts intact
-            _("Monotone\t1\tMT\n") + \
+            _("Version Control\t1\tCVS .svn MT [{]arch[}] .arch-ids .arch-inventory\n") + \
             #TRANSLATORS: translate this string ONLY to the first "\t", leave it and the following parts intact
             _("Binaries\t1\t*.{pyc,a,obj,o,so,la,lib,dll}\n") + \
             #TRANSLATORS: translate this string ONLY to the first "\t", leave it and the following parts intact
@@ -759,6 +758,7 @@ class MeldApp(gnomeglade.GnomeApp):
         doc = dirdiff.DirDiff(self.prefs, len(dirs))
         self._append_page(doc, "tree-folder-normal.png")
         doc.set_locations(dirs)
+        return doc
 
     def append_filediff(self, files):
         assert len(files) in (1,2,3)
@@ -769,6 +769,7 @@ class MeldApp(gnomeglade.GnomeApp):
         seq.connect("can-redo", self.on_can_redo)
         self._append_page(doc, "tree-file-normal.png")
         doc.set_files(files)
+        return doc
 
     def append_diff(self, paths):
         aredirs = [ os.path.isdir(p) for p in paths ]
@@ -778,9 +779,9 @@ class MeldApp(gnomeglade.GnomeApp):
                     parent = self,
                     buttonstype = gtk.BUTTONS_OK)
         elif 1 in aredirs:
-            self.append_dirdiff(paths)
+            return self.append_dirdiff(paths)
         else:
-            self.append_filediff(paths)
+            return self.append_filediff(paths)
 
     def append_vcview(self, locations):
         assert len(locations) in (1,)
@@ -788,6 +789,7 @@ class MeldApp(gnomeglade.GnomeApp):
         doc = vcview.VcView(self.prefs)
         self._append_page(doc, "vc-icon.png")
         doc.set_location(location)
+        return doc
 
     #
     # Current doc actions
@@ -820,22 +822,6 @@ class MeldApp(gnomeglade.GnomeApp):
 # usage
 #
 ################################################################################
-usage_string = _("""Meld is a file and directory comparison tool. Usage:
-
-    meld                        Start with no windows open
-    meld <dir>                  Start with VC browser in 'dir'
-    meld <file>                 Start with VC diff of 'file'
-    meld <file> <file> [file]   Start with 2 or 3 way file comparison
-    meld <dir>  <dir>  [dir]    Start with 2 or 3 way directory comparison
-
-Options:
-    -h, --help                  Show this help text and exit
-    -v, --version               Display the version and exit
-
-For more information choose help -> contents.
-Report bugs at http://bugzilla.gnome.org/buglist.cgi?product=meld
-Discuss meld at http://mail.gnome.org/mailman/listinfo/meld-list
-""")
 
 version_string = _("""Meld %s
 Written by Stephen Kennedy <stevek@gnome.org>""") % version
@@ -846,6 +832,7 @@ Written by Stephen Kennedy <stevek@gnome.org>""") % version
 #
 ################################################################################
 def main():
+    import optparse
     class Unbuffered(object):
         def __init__(self, file):
             self.file = file
@@ -855,17 +842,25 @@ def main():
         def __getattr__(self, attr):
             return getattr(self.file, attr)
     sys.stdout = Unbuffered(sys.stdout)
-    args = sys.argv[1:]
 
-    if args:
-        if "-h" in args or "--help" in args:
-            print usage_string
-            return
-        if "-v" in args or "--version" in args:
-            print version_string
-            return
+    parser = optparse.OptionParser(
+    usage="""
+    %prog                       Start with no windows open
+    %prog <dir>                 Start with VC browser in 'dir'
+    %prog <file>                Start with VC diff of 'file'
+    %prog <file> <file> [file]  Start with 2 or 3 way file comparison
+    %prog <dir>  <dir>  [dir]   Start with 2 or 3 way directory comparison""",
+    description="""Meld is a file and directory comparison tool.""",
+    version="%prog "+version)
+    parser.add_option("-L", "--label", action="append", default=[], help=_("Set label to use instead of file name"))
+    parser.add_option("-u", "--unified", action="store_true", help=_("Ignored for compatibility"))
+    parser.add_option("-c", "--context", action="store_true", help=_("Ignored for compatibility"))
+    parser.add_option("-e", "--ed", action="store_true", help=_("Ignored for compatibility"))
+    parser.add_option("-r", "--recursive", action="store_true", help=_("Ignored for compatibility"))
+    options, args = parser.parse_args()
 
     app = MeldApp()
+    tab = None
 
     if len(args) == 0:
         pass
@@ -882,12 +877,14 @@ def main():
             doc.connect("create-diff", lambda obj,arg: app.append_diff(arg) )
             doc.run_diff([a])
         else:
-            app.append_vcview( [a] )
+            tab = app.append_vcview( [a] )
                 
     elif len(args) in (2,3):
-        app.append_diff(args)
+        tab = app.append_diff(args)
     else:
         app.usage( _("Wrong number of arguments (Got %i)") % len(args))
 
+    if tab:
+        tab.set_labels( options.label )
     app.main()
 
